@@ -4,8 +4,10 @@ import pathlib
 
 import appdirs
 
-#: default settings file name
-NAME = "pyjibe.cfg"
+#: application name
+NAME = "PyJibe"
+#: application author
+ORG = "AFM-Analysis"
 
 #: default configuration parameters
 DEFAULTS = {}
@@ -14,13 +16,14 @@ DEFAULTS = {}
 class SettingsFile(object):
     """Manages a settings file in the user's config dir"""
 
-    def __init__(self, name=NAME, defaults=DEFAULTS, directory=None):
+    def __init__(self, name=NAME, org=ORG, defaults=DEFAULTS, directory=None):
         """Initialize settings file (create if it does not exist)"""
         if directory is None:
-            directory = appdirs.user_config_dir()
-        fname = pathlib.Path(directory) / name
+            directory = appdirs.user_config_dir(appname=name, appauthor=org)
+        fname = pathlib.Path(directory) / (name.replace(" ", "_") + ".cfg")
         # create file if not existent
         if not fname.exists():
+            fname.parent.mkdir(exist_ok=True, parents=True)
             # Create the file
             fname.open("w").close()
 
